@@ -13,8 +13,7 @@
 
 
 harmonic_mean <- function(x){
-  if(! all(x >= 0)){
-    return(NA)   
-    }
- return(1/mean(1/x))
+  if(any(is.na(x))) return(NA)
+  if(any(x < 0)) return(NA)
+  return(1/mean(1/x))
 }
